package com.benyun.core.init;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.benyun.core.dao.AddrCategoryDao;
import com.benyun.core.dao.TypeByDao;
import com.benyun.core.entity.AddrCategory;
import com.benyun.core.entity.ManageType;
import com.benyun.core.entity.TypeBy;
import com.benyun.core.service.ManageTypeService;
import com.benyun.core.utils.HashUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.concurrent.*;

@Configuration
public class BenyunCoreInit {
    @Autowired
    AddrCategoryDao addrCategoryDao;

    @Autowired
    ManageTypeService manageTypeService;

    @Autowired
    TypeByDao byDao;

    @Bean("executor")
    public ExecutorService getExecutor(){
        return Executors.newFixedThreadPool(10);
    }

    /**
     * HashMap<地区Code,城市等级>
     * */
    @Bean("cityTierMap")
    public HashMap<String, String> getCityTierMap(){
        HashMap<String, String> hashMap = new HashMap<>();

        QueryWrapper<AddrCategory> queryWrapper = new QueryWrapper<>();
        queryWrapper.isNotNull("city_tier");
        for (AddrCategory addrCategory : addrCategoryDao.selectList(queryWrapper)) {
            if(addrCategory.getCityTier() != null && !addrCategory.getCityTier().equals("")){
                hashMap.put(addrCategory.getAddrCode().substring(0,4), addrCategory.getCityTier());
            }
        }
        return hashMap;
    }

    /**
     * 一线城市的addrCode
     * */
    @Bean("cityTierListMap")
    public HashMap<String,List<String>> getCityTierListMap(){
        List<String> one = new ArrayList<>();
        List<String> two = new ArrayList<>();
        List<String> three = new ArrayList<>();
        List<String> four = new ArrayList<>();
        List<String> five = new ArrayList<>();

        HashMap<String, String> cityTierMap = getCityTierMap();
        for (String s : cityTierMap.keySet()) {
            String s1 = cityTierMap.get(s);
            switch (s1){
                case "一线":
                    one.add(s);
                    break;
                case "二线":
                    two.add(s);
                    break;
                case "三线":
                    three.add(s);
                    break;
                case "四线":
                    four.add(s);
                    break;
                case "五线":
                    five.add(s);
                    break;
            }
        }
        HashMap<String,List<String>> util = new HashMap<>();
        util.put("一线",one);
        util.put("二线",two);
        util.put("三线",three);
        util.put("四线",four);
        util.put("五线",five);
        return util;
    }




    @Bean("ManageType")
    public HashMap getManageType(){
        HashMap<String,ManageType> hashMap = new HashMap<>();
        for (ManageType datum : manageTypeService.getData()) {
            if(!datum.getManageTypeCode().equals(""))
                hashMap.put(datum.getManageTypeCode(),datum);
        }
        return hashMap;
    }


    @Bean("addrCodeMap")
    public HashMap getAddrCodeMap(){
        HashMap<String,String> hashMap = new HashMap<>();
        for (AddrCategory addrCode : addrCategoryDao.selectList(null)) {
            hashMap.put(addrCode.getAddrCode(),addrCode.getAddrInfo());
        }
        return hashMap;
    }

    @Bean("typeByMap")
    public HashMap getTypeByMap(){
        HashMap<String,String> hashMap = new HashMap<>();
        for (TypeBy datum : byDao.selectList(null)) {
            hashMap.put(datum.getTypeCodeBy(),datum.getFullInfo());
        }
        return hashMap;
    }
}
